..
   Template for the html base rendering

   Modified from
   https://github.com/sphinx-doc/sphinx/tree/master/sphinx/ext/autosummary/templates/autosummary/base.rst

lbfgsb.bfgsmats.form\_invMfactors
=================================

.. currentmodule:: lbfgsb.bfgsmats

.. autofunction:: form_invMfactors